#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_grr_zone import SchGRRZone
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchZoneGraphic(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchZoneGraphic
                | 
                | Manage graphical representations of a schematic zone.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_zone_graphic = com_object

    def add_graphical_representation(self, i_grr_to_add: SchGRRZone) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddGraphicalRepresentation(SchGRRZone iGRRToAdd)
                | 
                |     Add a graphical representation to a zone.
                | 
                |     Parameters:
                | 
                |         iGRRToAdd
                |             The graphical representation to be added to the zone.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchZoneGraphic
                |          Dim objArg1 As SchGRRZone
                |           ...
                |          objThisIntf.AddGraphicalRepresentationobjArg1

        :param SchGRRZone i_grr_to_add:
        :rtype: None
        """
        return self.sch_zone_graphic.AddGraphicalRepresentation(i_grr_to_add.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_graphical_representation'
        # # vba_code = """
        # # Public Function add_graphical_representation(sch_zone_graphic)
        # #     Dim iGRRToAdd (2)
        # #     sch_zone_graphic.AddGraphicalRepresentation iGRRToAdd
        # #     add_graphical_representation = iGRRToAdd
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def list_graphical_representations(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListGraphicalRepresentations() As SchListOfObjects
                | 
                |     List all graphical representations of a zone.
                | 
                |     Parameters:
                | 
                |         oLGRR
                |             A list of graphical representations (members are CATISchGRRZone
                |             interface pointers). 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchZoneGraphic
                |          Dim objArg1 As SchListOfObjects
                |           ...
                |          Set objArg1 = objThisIntf.ListGraphicalRepresentations

        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_zone_graphic.ListGraphicalRepresentations())

    def remove_graphical_representation(self, i_grr_to_remove: SchGRRZone) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveGraphicalRepresentation(SchGRRZone iGRRToRemove)
                | 
                |     Remove a graphical representation from a zone.
                | 
                |     Parameters:
                | 
                |         iGRRToRemove
                |             The graphical representation to be removed from the zone.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchZoneGraphic
                |          Dim objArg1 As SchGRRZone
                |           ...
                |          objThisIntf.RemoveGraphicalRepresentationobjArg1

        :param SchGRRZone i_grr_to_remove:
        :rtype: None
        """
        return self.sch_zone_graphic.RemoveGraphicalRepresentation(i_grr_to_remove.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_graphical_representation'
        # # vba_code = """
        # # Public Function remove_graphical_representation(sch_zone_graphic)
        # #     Dim iGRRToRemove (2)
        # #     sch_zone_graphic.RemoveGraphicalRepresentation iGRRToRemove
        # #     remove_graphical_representation = iGRRToRemove
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchZoneGraphic(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_activity import ManufacturingActivity


class ManufacturingCopyTransformation(ManufacturingActivity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                        ManufacturingInterfaces.ManufacturingActivity
                |                             ManufacturingCopyTransformation
                | 
                | Interface representing the Manufacturing Copy Transformation
                | object.
                | 
                | Role: Component that implements CATIAManufacturingCopyOrder is MfgCopyOrder.
                | This interface allows to modify the Copy Tranformation and to get the start and
                | end points of the computed trajectory.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_copy_transformation = com_object

    def add_operation(self, i_manufacturing_activity: ManufacturingActivity) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddOperation(ManufacturingActivity
                | iManufacturingActivity)
                | 
                |     Add a Manufacturing Operation to a Copy Transformation.
                | 
                |     Example:
                |         The following example adds a manufacturing operation myOperation, as a
                |         reference for the Copy Transformation
                |         CopyTransformation
                | 
                |          call myOperation.AddOperation(CopyTransformation)

        :param ManufacturingActivity i_manufacturing_activity:
        :rtype: None
        """
        return self.manufacturing_copy_transformation.AddOperation(i_manufacturing_activity.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_operation'
        # # vba_code = """
        # # Public Function add_operation(manufacturing_copy_transformation)
        # #     Dim iManufacturingActivity (2)
        # #     manufacturing_copy_transformation.AddOperation iManufacturingActivity
        # #     add_operation = iManufacturingActivity
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_trajectory_end_point_coord(self, o_end_point: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTrajectoryEndPointCoord(CATSafeArrayVariant
                | oEndPoint)
                | 
                |     Retrieves the Manufacturing Copy Order trajectory end
                |     point.
                | 
                |     Example:
                |         The following example retrieves in oEndPoint the end point of the
                |         Manufacturing Copy Order CopyOrder
                | 
                |          Dim oEndPoint(3)
                |          call CopyOrder.GetTrajectoryEndPointCoord(oEndPoint)
                |          x = oEndPoint(0)
                |          y = oEndPoint(1)
                |          z = oEndPoint(2)

        :param tuple o_end_point:
        :rtype: None
        """
        return self.manufacturing_copy_transformation.GetTrajectoryEndPointCoord(o_end_point)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_trajectory_end_point_coord'
        # # vba_code = """
        # # Public Function get_trajectory_end_point_coord(manufacturing_copy_transformation)
        # #     Dim oEndPoint (2)
        # #     manufacturing_copy_transformation.GetTrajectoryEndPointCoord oEndPoint
        # #     get_trajectory_end_point_coord = oEndPoint
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_trajectory_start_point_coord(self, o_start_point: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTrajectoryStartPointCoord(CATSafeArrayVariant
                | oStartPoint)
                | 
                |     Retrieves the Manufacturing Copy Order Operation's trajectory start
                |     point.
                | 
                |     Example:
                |         The following example retrieves in oStartPoint the start point of the
                |         Machining Operation Operation
                | 
                |          Dim oStartPoint(3)
                |          call
                |          Operation.GetTrajectoryStartPointCoord(oStartPoint)
                |          x = oStartPoint(0)
                |          y = oStartPoint(1)
                |          z = oStartPoint(2)

        :param tuple o_start_point:
        :rtype: None
        """
        return self.manufacturing_copy_transformation.GetTrajectoryStartPointCoord(o_start_point)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_trajectory_start_point_coord'
        # # vba_code = """
        # # Public Function get_trajectory_start_point_coord(manufacturing_copy_transformation)
        # #     Dim oStartPoint (2)
        # #     manufacturing_copy_transformation.GetTrajectoryStartPointCoord oStartPoint
        # #     get_trajectory_start_point_coord = oStartPoint
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_copy_transformation(self, i_number_of_copies: int, i_ordering: str, i_transformation_type: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCopyTransformation(long iNumberOfCopies,
                | CATBSTR iOrdering,
                | CATBSTR iTransformationType)
                | 
                |     Set the 'Number of Copies', 'Ordering' and 'Transformation Type' of a Copy
                |     Tranformation.
                | 
                |     Parameters:
                | 
                |         iOrdering
                |             Legal values: iOrdering can be
                | 
                |             "EachOperationNTime"
                |             "AllOperationsNTime"
                | 
                |         iTransformationType
                |             Legal values: iTransformationType can be
                | 
                |             "Translation"
                |             "Rotation"
                |             "Mirror"
                |             "AxisToAxis"
                |             "Scale"
                |             "Affinity"
                |             "Matrix"
                | 
                |         Example:
                |             The following example does that for the Copy Transformation
                |             CopyTransformation :
                | 
                |              call CopyTransformation.SetCopyTransformation(iNumberOfCopies,
                |              "EachOperationNTime", "Translation")

        :param int i_number_of_copies:
        :param str i_ordering:
        :param str i_transformation_type:
        :rtype: None
        """
        return self.manufacturing_copy_transformation.SetCopyTransformation(
            i_number_of_copies,
            i_ordering,
            i_transformation_type
        )

    def set_copy_transformation_translation_attributes(
            self,
            i_translation_type: str,
            i_distance_along_x: float,
            i_distance_along_y: float,
            i_distance_along_z: float
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCopyTransformationTranslationAttributes(CATBSTR
                | iTranslationType,
                | double iDistanceAlongX,
                | double iDistanceAlongY,
                | double iDistanceAlongZ)
                | 
                |     Set the 'Translation Type', 'Distance Along X', 'Distance Along Y' and
                |     'Distance Along Z' of a Copy Tranformation which has a Translation as
                |     transformation.
                | 
                |     Parameters:
                | 
                |         iTranslationType
                |             Legal values: iTranslationType can be
                | 
                |             "AbsoluteCoordinates"
                |             "CurrentCoordinates"
                | 
                |         iDistanceAlongX
                |             distance along X in mm. 
                |         iDistanceAlongY
                |             distance along Y in mm. 
                |         iDistanceAlongZ
                |             distance along Z in mm. 
                |         Example:
                |             The following example does that for the Copy Transformation
                |             CopyTransformation :
                | 
                |              call
                |              CopyTransformation.SetCopyTransformationTranslationAttributes("AbsoluteCoordinates", 0.0, 100.0, 0.0
                |              )

        :param str i_translation_type:
        :param float i_distance_along_x:
        :param float i_distance_along_y:
        :param float i_distance_along_z:
        :rtype: None
        """
        return self.manufacturing_copy_transformation.SetCopyTransformationTranslationAttributes(
            i_translation_type,
            i_distance_along_x,
            i_distance_along_y,
            i_distance_along_z
        )

    def __repr__(self):
        return f'ManufacturingCopyTransformation(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_activity import ManufacturingActivity
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingSetup2(ManufacturingActivity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                        ManufacturingInterfaces.ManufacturingActivity
                |                             ManufacturingSetup2
                | 
                | A ManufacturingSetup 2 for a Manufacturing Document.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_setup2 = com_object

    def create_resource_from_catalog(
            self,
            i_tool_resource_name: str,
            i_resource_type: str,
            i_catalog_path: str
    ) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateResourceFromCatalog(CATBSTR iToolResourceName,
                | CATBSTR iResourceType,
                | CATBSTR iCatalogPath) As AnyObject
                | 
                |     This method is used to create a new manufacturing resource from
                |     catalog.

        :param str i_tool_resource_name:
        :param str i_resource_type:
        :param str i_catalog_path:
        :rtype: AnyObject
        """
        return AnyObject(
            self.manufacturing_setup2.CreateResourceFromCatalog(
                i_tool_resource_name,
                i_resource_type,
                i_catalog_path
            )
        )

    def __repr__(self):
        return f'ManufacturingSetup2(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class EhsUpdateSmoothnessFactor(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     EHSUpdateSmoothnessFactor
                | 
                | Interface representing xxx.
                | 
                | Role: Components that implement DNBIAEHSUpdateSmoothnessFactor are
                | ...
                | 
                | Do not use the DNBIAEHSUpdateSmoothnessFactor interface for such and such
                | ClassReference, Class#MethodReference, #InternalMethod...
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.ehs_update_smoothness_factor = com_object

    def update_bundle_smoothness(self, i_smoothness_factor: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UpdateBundleSmoothness(short iSmoothnessFactor)
                | 
                |     Sets Smoothness Factor for Bundle segment.
                | 
                |     Parameters:
                | 
                |         iSmoothnessFactor
                |             the input smoothness factor. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :param int i_smoothness_factor:
        :rtype: None
        """
        return self.ehs_update_smoothness_factor.UpdateBundleSmoothness(i_smoothness_factor)

    def __repr__(self):
        return f'EhsUpdateSmoothnessFactor(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_sensor import AnalysisSensor


class AnalysisLocalSensor(AnalysisSensor):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATAnalysisInterfaces.AnalysisEntity
                |                         CATAnalysisInterfaces.AnalysisSensor
                |                             AnalysisLocalSensor
                | 
                | Represent the analysis local sensor.
                | 
                | This object is a kind of AnalysisSensor based on analysis feature
                | results
                | based on a finite element selection. This sensor definition is based on an XML
                | file
                | stored in the CATIARuntimeView.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_local_sensor = com_object

    @property
    def xml_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property XMLName() As CATBSTR
                | 
                |     Returns or sets the Identifier of the sensor as defined in the XML
                |     file.
                | 
                |     Example:
                |         This example retrieves in MyXMLName the identifier of the
                |         AnalysisSensor1 object.
                | 
                |          MyObjectName = AnalysisSensor1.XMLName

        :rtype: str
        """

        return self.analysis_local_sensor.XMLName

    @xml_name.setter
    def xml_name(self, value: str):
        """
        :param str value:
        """

        self.analysis_local_sensor.XMLName = value

    def __repr__(self):
        return f'AnalysisLocalSensor(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_feature import ManufacturingFeature
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingMachiningAxis(ManufacturingFeature):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                    ManufacturingInterfaces.ManufacturingFeature
                |                         ManufacturingMachiningAxis
                | 
                | ManufacturingMachiningAxis defines a set of methods to manage a Machining Axis
                | System or an Origin.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_machining_axis = com_object

    @property
    def origin(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Origin() As short
                | 
                |     This property returns the interface which manages if instruction os used as
                |     an Origin or as a Machining Axis System. If instruction is an Origin, Origin is
                |     set to 1, 0 otherwise.
                | 
                |     Example:
                |         The following example returns in origin the attribute to provide if
                |         instruction is used as a Machining Axis System or an Origin
                |         :
                | 
                |          ...
                |          Set myInstruction  = ... 
                |          Set MyOrigin = myInstruction.Origin

        :rtype: int
        """

        return self.manufacturing_machining_axis.Origin

    @origin.setter
    def origin(self, value: int):
        """
        :param int value:
        """

        self.manufacturing_machining_axis.Origin = value

    @property
    def origin_group(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OriginGroup() As short
                | 
                |     This property returns the interface which determines the origin group of
                |     the instruction if used a an Origin.
                | 
                |     Example:
                |         The following example set the Origin Group to 5.
                | 
                |          ...
                |          Set myInstruction  = ... 
                |          Set myInstruction.OriginGroup = 3

        :rtype: int
        """

        return self.manufacturing_machining_axis.OriginGroup

    @origin_group.setter
    def origin_group(self, value: int):
        """
        :param int value:
        """

        self.manufacturing_machining_axis.OriginGroup = value

    @property
    def origin_number(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OriginNumber() As short
                | 
                |     This property returns the interface which manages the origin number of the
                |     instruction if used a an Origin.
                | 
                |     Example:
                |         The following example set the Origin Number to 3.
                | 
                |          ...
                |          Set myInstruction  = ... 
                |          Set myInstruction.OriginNumber = 3

        :rtype: int
        """

        return self.manufacturing_machining_axis.OriginNumber

    @origin_number.setter
    def origin_number(self, value: int):
        """
        :param int value:
        """

        self.manufacturing_machining_axis.OriginNumber = value

    def get_origin_point(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetOriginPoint(double x,
                | double y,
                | double z)
                | 
                |     Gets the Origin of a Manufacturing Machining Axis System used as
                |     Origin.
                | 
                |     Example:
                |         The following example gets MfgAxisSystem with PointOrigin as an Origin
                |         Point and with ProductOrigin a belonging product.
                | 
                |          Dim MfgAxisSystem As ManufacturingMachiningAxis
                |          Set MfgAxisSystem = ...
                |          Dim PointOrigin As CATSafeArrayVariant
                |          Dim ProductOrigin As Product
                |          MfgAxisSystem.GetOriginPoint (PointOrigin)

        :rtype: tuple
        """
        return self.manufacturing_machining_axis.GetOriginPoint()

    def get_origin_x_direction(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetOriginXDirection(double x,
                | double y,
                | double z)
                | 
                |     Gets the Origin X direction of a Manufacturing Machining Axis System used
                |     as Origin.
                | 
                |     Example:
                |         The following example gets MfgAxisSystem with origin X direction in
                |         DblMathDirection.
                | 
                |          Dim DlbMathDirection As Double(3)
                |          Dim MfgAxisSystem As ManufacturingMachiningAxis
                |          Set MfgAxisSystem = ...
                |          MfgAxisSystem.GetOriginXDirection (DblMathDirection)

        :rtype: tuple
        """
        return self.manufacturing_machining_axis.GetOriginXDirection()

    def get_origin_y_direction(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetOriginYDirection(double x,
                | double y,
                | double z)
                | 
                |     Gets the Origin Y direction of a Manufacturing Machining Axis System used
                |     as Origin.
                | 
                |     Example:
                |         The following example gets MfgAxisSystem with origin Y direction in
                |         DblMathDirection.
                | 
                |          Dim DlbMathDirection As Double(3)
                |          Dim MfgAxisSystem As ManufacturingMachiningAxis
                |          Set MfgAxisSystem = ...
                |          MfgAxisSystem.GetOriginYDirection (DblMathDirection)

        :rtype: tuple
        """
        return self.manufacturing_machining_axis.GetOriginYDirection()

    def get_origin_z_direction(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetOriginZDirection(double x,
                | double y,
                | double z)
                | 
                |     Gets the Origin Z direction of a Manufacturing Machining Axis System used
                |     as Origin.
                | 
                |     Example:
                |         The following example gets MfgAxisSystem with origin Z direction in
                |         DblMathDirection.
                | 
                |          Dim x,y,z As Double
                |          Dim MfgAxisSystem As ManufacturingMachiningAxis
                |          Set MfgAxisSystem = ...
                |          MfgAxisSystem.GetOriginZDirection (x,y,z)

        :rtype: tuple
        """
        return self.manufacturing_machining_axis.GetOriginZDirection()

    def set_origin_point(self, i_point: AnyObject, i_product: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOriginPoint(AnyObject iPoint,
                | AnyObject iProduct)
                | 
                |     Sets the Origin of a Manufacturing Machining Axis System used as
                |     Origin.
                | 
                |     Example:
                |         The following example sets MfgAxisSystem with PointOrigin as an Origin
                |         Point and with ProductOrigin a belonging product.
                | 
                |          Dim MfgAxisSystem As ManufacturingMachiningAxis
                |          Set MfgAxisSystem = ...
                |          Dim PointOrigin As AnyObject
                |          Dim ProductOrigin As Product
                |          MfgAxisSystem.SetOriginPoint
                |          (PointOrigin,ProductOrigin)

        :param AnyObject i_point:
        :param AnyObject i_product:
        :rtype: None
        """
        return self.manufacturing_machining_axis.SetOriginPoint(i_point.com_object, i_product.com_object)

    def set_origin_point_by_coordinates(self, x: float, y: float, z: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOriginPointByCoordinates(double x,
                | double y,
                | double z)
                | 
                |     Sets the Origin of a Manufacturing Machining Axis System used as Origin by
                |     coordinates.
                | 
                |     Example:
                |         The following example sets the Origin MfgAxisSystem at coordinates
                |         x,y,z.
                | 
                |          Dim MfgAxisSystem As ManufacturingMachiningAxis
                |          Set MfgAxisSystem = ...
                |          MfgAxisSystem.SetOriginPointByCoordinates(x,y,z)

        :param float x:
        :param float y:
        :param float z:
        :rtype: None
        """
        return self.manufacturing_machining_axis.SetOriginPointByCoordinates(x, y, z)

    def set_origin_x_direction(self, x: float, y: float, z: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOriginXDirection(double x,
                | double y,
                | double z)
                | 
                |     Sets the Origin X direction of a Manufacturing Machining Axis System used
                |     as Origin.
                | 
                |     Example:
                |         The following example sets MfgAxisSystem with origin X direction in
                |         DblMathDirection.
                | 
                |          Dim DlbMathDirection As Double(3)
                |          Dim MfgAxisSystem As ManufacturingMachiningAxis
                |          Set MfgAxisSystem = ...
                |          MfgAxisSystem.SetOriginXDirection (DblMathDirection)

        :param float x:
        :param float y:
        :param float z:
        :rtype: None
        """
        return self.manufacturing_machining_axis.SetOriginXDirection(x, y, z)

    def set_origin_z_direction(self, x: float, y: float, z: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOriginZDirection(double x,
                | double y,
                | double z)
                | 
                |     Sets the Origin Z direction of a Manufacturing Machining Axis System used
                |     as Origin.
                | 
                |     Example:
                |         The following example sets MfgAxisSystem with origin Y direction in
                |         DblMathDirection.
                | 
                |          Dim x,y,z As Double
                |          Dim MfgAxisSystem As ManufacturingMachiningAxis
                |          Set MfgAxisSystem = ...
                |          MfgAxisSystem.SetOriginZDirection (x,y,z)

        :param float x:
        :param float y:
        :param float z:
        :rtype: None
        """
        return self.manufacturing_machining_axis.SetOriginZDirection(x, y, z)

    def set_part_axis_system(self, i_pas: AnyObject, i_product: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPartAxisSystem(AnyObject iPAS,
                | AnyObject iProduct)
                | 
                |     Sets the Part Axis System of a Manufacturing Machining Axis
                |     System.
                | 
                |     Example:
                |         The following example sets MfgAxisSystem with PAS as a Part Axis System
                |         and with ProductPAS a belonging product.
                | 
                |          Dim MfgAxisSystem As ManufacturingMachiningAxis
                |          Set MfgAxisSystem = ...
                |          Dim PAS As AxisSystem
                |          Dim PASProduct As Product
                |          MfgAxisSystem.SetMachiningAxisSystem (PAS,PASProduct)

        :param AnyObject i_pas:
        :param AnyObject i_product:
        :rtype: None
        """
        return self.manufacturing_machining_axis.SetPartAxisSystem(i_pas.com_object, i_product.com_object)

    def __repr__(self):
        return f'ManufacturingMachiningAxis(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_fastener_interfaces.fastener import Fastener


class CurveFastener(Fastener):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DNBFastenerInterfaces.Fastener
                |                         CurveFastener
                | 
                | Interface DELMIACurveFastener DELMIACurveFastener represent body in white
                | fasteners of type curve.
                | Following kind of curve fasteners are by default available with DPM - Fastening
                | Process Planner Adhesive Curve, Arc Weld, Sealant Curve, Glue
                | Bead.
                | 
                | Copyright © 1999-2011, Dassault Systèmes. All rights reserved.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.curve_fastener = com_object

    def __repr__(self):
        return f'CurveFastener(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_interaction import ABQInteraction
from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.body import Body
from pycatia.mec_mod_interfaces.part import Part
from pycatia.product_structure_interfaces.product import Product
from pycatia.product_structure_interfaces.publication import Publication


class ABQRigidBodyConstraint(ABQInteraction):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQInteraction
                |                         ABQRigidBodyConstraint
                | 
                | Represents an Abaqus rigid body constraint (ABQRigidBodyConstraint)
                | object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_rigid_body_constraint = com_object

    @property
    def move_to_center_of_mass(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MoveToCenterOfMass() As boolean
                | 
                |     Sets or returns the move to center of mass flag.

        :rtype: bool
        """

        return self.abq_rigid_body_constraint.MoveToCenterOfMass

    @move_to_center_of_mass.setter
    def move_to_center_of_mass(self, value: bool):
        """
        :param bool value:
        """

        self.abq_rigid_body_constraint.MoveToCenterOfMass = value

    @property
    def num_pin_supports(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NumPinSupports() As long (Read Only)
                | 
                |     Gets the number of pin point supports for the rigid body.

        :rtype: int
        """

        return self.abq_rigid_body_constraint.NumPinSupports

    @property
    def num_tie_supports(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NumTieSupports() As long (Read Only)
                | 
                |     Gets the number of tie point supports for the rigid body.

        :rtype: int
        """

        return self.abq_rigid_body_constraint.NumTieSupports

    def add_support_from_body(self, i_product: Product, i_body: Body) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromBody(Product iProduct,
                | Body iBody)
                | 
                |     Creates a new support for the body and adds it to the description of the
                |     Analysis Entity.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIAProduct specifying the positioning
                |             object.
                |         iBody
                |             The CATIABody specifying the object that is being pointed
                |             to.
                | 
                |             Refer: CATIABody , CATIAProduct

        :param Product i_product:
        :param Body i_body:
        :rtype: None
        """
        return self.abq_rigid_body_constraint.AddSupportFromBody(i_product.com_object, i_body.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_body'
        # # vba_code = """
        # # Public Function add_support_from_body(abq_rigid_body_constraint)
        # #     Dim iProduct (2)
        # #     abq_rigid_body_constraint.AddSupportFromBody iProduct
        # #     add_support_from_body = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_part(self, i_product: Product, i_part: Part) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromPart(Product iProduct,
                | Part iPart)
                | 
                |     Creates a new support for the part and adds it to the description of the
                |     Analysis Entity.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIAProduct specifying the positioning
                |             object.
                |         iSupport
                |             The CATIAPart specifying the object that is being pointed
                |             to.
                | 
                |             Refer: CATIAPart , CATIAProduct

        :param Product i_product:
        :param Part i_part:
        :rtype: None
        """
        return self.abq_rigid_body_constraint.AddSupportFromPart(i_product.com_object, i_part.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_part'
        # # vba_code = """
        # # Public Function add_support_from_part(abq_rigid_body_constraint)
        # #     Dim iProduct (2)
        # #     abq_rigid_body_constraint.AddSupportFromPart iProduct
        # #     add_support_from_part = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_publication(self, i_product: Product, i_publication: Publication) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromPublication(Product iProduct,
                | Publication iPublication)
                | 
                |     Adds a support to the Rigid body constraint. If the support already exists,
                |     it is removed.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIA Product specifying the object to which the rigid body
                |             constraint is applied.
                |         iPublication
                |             The CATIA Publication specifying the region to which the rigid body
                |             constraint is applied.
                | 
                |             Refer: CATIAPublication

        :param Product i_product:
        :param Publication i_publication:
        :rtype: None
        """
        return self.abq_rigid_body_constraint.AddSupportFromPublication(i_product.com_object, i_publication.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_publication'
        # # vba_code = """
        # # Public Function add_support_from_publication(abq_rigid_body_constraint)
        # #     Dim iProduct (2)
        # #     abq_rigid_body_constraint.AddSupportFromPublication iProduct
        # #     add_support_from_publication = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def clear_pin_supports(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ClearPinSupports()
                | 
                |     Clears the pin point supports for the rigid body.

        :rtype: None
        """
        return self.abq_rigid_body_constraint.ClearPinSupports()

    def clear_tie_supports(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ClearTieSupports()
                | 
                |     Clears the tie point supports for the rigid body.

        :rtype: None
        """
        return self.abq_rigid_body_constraint.ClearTieSupports()

    def get_pin_supports(self, i_products: tuple, i_regions: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetPinSupports(CATSafeArrayVariant iProducts,
                | CATSafeArrayVariant iRegions)
                | 
                |     Gets the pin point supports for the rigid body.
                | 
                |     Parameters:
                | 
                |         oProducts
                |             Safe array of products for the support region as CATIReferences.
                |             This array has a one-to-one mapping with the regions array.
                |             
                |         oRegions
                |             Safe array of supports as CATIReferences. This array has a
                |             one-to-one mapping with the products array.

        :param tuple i_products:
        :param tuple i_regions:
        :rtype: None
        """
        return self.abq_rigid_body_constraint.GetPinSupports(i_products, i_regions)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_pin_supports'
        # # vba_code = """
        # # Public Function get_pin_supports(abq_rigid_body_constraint)
        # #     Dim iProducts (2)
        # #     abq_rigid_body_constraint.GetPinSupports iProducts
        # #     get_pin_supports = iProducts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_tie_supports(self, i_products: tuple, i_regions: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTieSupports(CATSafeArrayVariant iProducts,
                | CATSafeArrayVariant iRegions)
                | 
                |     Gets the tie point supports for the rigid body.
                | 
                |     Parameters:
                | 
                |         oProducts
                |             Safe array of products for the support region as CATIReferences.
                |             This array has a one-to-one mapping with the regions array.
                |             
                |         oRegions
                |             Safe array of supports as CATIReferences. This array has a
                |             one-to-one mapping with the products array.

        :param tuple i_products:
        :param tuple i_regions:
        :rtype: None
        """
        return self.abq_rigid_body_constraint.GetTieSupports(i_products, i_regions)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_tie_supports'
        # # vba_code = """
        # # Public Function get_tie_supports(abq_rigid_body_constraint)
        # #     Dim iProducts (2)
        # #     abq_rigid_body_constraint.GetTieSupports iProducts
        # #     get_tie_supports = iProducts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_handler(self, i_product: Product, i_ref: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetHandler(Product iProduct,
                | Reference iRef)
                | 
                |     Set the handler for the rigid body.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIAProduct specifying the positioning
                |             object.
                |         iRef
                |             The CATIAReference specifying the object that is being pointed
                |             to.

        :param Product i_product:
        :param Reference i_ref:
        :rtype: None
        """
        return self.abq_rigid_body_constraint.SetHandler(i_product.com_object, i_ref.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_handler'
        # # vba_code = """
        # # Public Function set_handler(abq_rigid_body_constraint)
        # #     Dim iProduct (2)
        # #     abq_rigid_body_constraint.SetHandler iProduct
        # #     set_handler = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_handler_from_publication(self, i_product: Product, i_publication: Publication) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetHandlerFromPublication(Product iProduct,
                | Publication iPublication)
                | 
                |     Sets the handler for the Rigid body constraint. Any previously set handler
                |     will be replaced with the new value.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIA Product for handeler.
                |         iPublication
                |             The CATIA Publication for handeler.
                | 
                |             Refer: CATIAPublication

        :param Product i_product:
        :param Publication i_publication:
        :rtype: None
        """
        return self.abq_rigid_body_constraint.SetHandlerFromPublication(i_product.com_object, i_publication.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_handler_from_publication'
        # # vba_code = """
        # # Public Function set_handler_from_publication(abq_rigid_body_constraint)
        # #     Dim iProduct (2)
        # #     abq_rigid_body_constraint.SetHandlerFromPublication iProduct
        # #     set_handler_from_publication = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_pin_supports(self, i_products: tuple, i_regions: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPinSupports(CATSafeArrayVariant iProducts,
                | CATSafeArrayVariant iRegions)
                | 
                |     Sets the pin point supports for the rigid body. Any previously set pin
                |     supports will be replaced with this new list. At least one item in the list is
                |     required.
                | 
                |     Parameters:
                | 
                |         iProducts
                |             Safe array of products for the support region as CATIReferences.
                |             This array has a one-to-one mapping with the regions array.
                |             
                |         iRegions
                |             Safe array of supports as CATIReferences. This array has a
                |             one-to-one mapping with the products array.

        :param tuple i_products:
        :param tuple i_regions:
        :rtype: None
        """
        return self.abq_rigid_body_constraint.SetPinSupports(i_products, i_regions)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_pin_supports'
        # # vba_code = """
        # # Public Function set_pin_supports(abq_rigid_body_constraint)
        # #     Dim iProducts (2)
        # #     abq_rigid_body_constraint.SetPinSupports iProducts
        # #     set_pin_supports = iProducts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_tie_supports(self, i_products: tuple, i_regions: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTieSupports(CATSafeArrayVariant iProducts,
                | CATSafeArrayVariant iRegions)
                | 
                |     Sets the tie point supports for the rigid body. Any previously set tie
                |     supports will be replaced with this new list. At least one item in the list is
                |     required.
                | 
                |     Parameters:
                | 
                |         iProducts
                |             Safe array of products for the support region as CATIReferences.
                |             This array has a one-to-one mapping with the regions array.
                |             
                |         iRegions
                |             Safe array of supports as CATIReferences. This array has a
                |             one-to-one mapping with the products array.

        :param tuple i_products:
        :param tuple i_regions:
        :rtype: None
        """
        return self.abq_rigid_body_constraint.SetTieSupports(i_products, i_regions)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_tie_supports'
        # # vba_code = """
        # # Public Function set_tie_supports(abq_rigid_body_constraint)
        # #     Dim iProducts (2)
        # #     abq_rigid_body_constraint.SetTieSupports iProducts
        # #     set_tie_supports = iProducts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQRigidBodyConstraint(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SchAppCntrFlow(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppCntrFlow
                | 
                | Manage the technical attributes of a schematic connector.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_cntr_flow = com_object

    def app_get_flow_capability(self, o_e_flow_capability: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppGetFlowCapability(CatSchIDLCntrFlowCapability
                | oEFlowCapability)
                | 
                |     Query the application Flow Capability property of this
                |     connector.
                | 
                |     Parameters:
                | 
                |         oEFlowCapability
                |             Flow Capability. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppCntrFlow
                | 
                |           ...
                |         objThisIntf.AppGetFlowCapabilityCatSchIDLCntrFlowCapability_Enum

        :param int o_e_flow_capability: enum cat_sch_idl_cntr_flow_capability
        :rtype: None
        """
        return self.sch_app_cntr_flow.AppGetFlowCapability(o_e_flow_capability)

    def app_get_flow_reality(self, o_e_flow_reality: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppGetFlowReality(CatSchIDLCntrFlowReality
                | oEFlowReality)
                | 
                |     Query the application Flow Reality property of this
                |     connector.
                | 
                |     Parameters:
                | 
                |         oEFlowReality
                |             Flow Reality. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchAppCntrFlow
                | 
                |           ...
                |         objThisIntf.AppGetFlowRealityCatSchIDLCntrFlowReality_Enum

        :param int o_e_flow_reality: enum cat_sch_idl_cntr_flow_reality
        :rtype: None
        """
        return self.sch_app_cntr_flow.AppGetFlowReality(o_e_flow_reality)

    def app_set_flow_capability(self, i_e_flow_capability: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppSetFlowCapability(CatSchIDLCntrFlowCapability
                | iEFlowCapability)
                | 
                |     Set the application Flow Capability property of this
                |     connector.
                | 
                |     Parameters:
                | 
                |         iEFlowCapability
                |             Flow Capability property to be set. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppCntrFlow
                | 
                |           ...
                |         objThisIntf.AppSetFlowCapabilityCatSchIDLCntrFlowCapability_Enum

        :param int i_e_flow_capability: enum cat_sch_idl_cntr_flow_capability
        :rtype: None
        """
        return self.sch_app_cntr_flow.AppSetFlowCapability(i_e_flow_capability)

    def app_set_flow_reality(self, i_e_flow_reality: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppSetFlowReality(CatSchIDLCntrFlowReality
                | iEFlowReality)
                | 
                |     Set the application Flow Reality property of this
                |     connector.
                | 
                |     Parameters:
                | 
                |         iEFlowReality
                |             Flow Reality property to be set. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppCntrFlow
                | 
                |           ...
                |         objThisIntf.AppSetFlowRealityCatSchIDLCntrFlowReality_Enum

        :param int i_e_flow_reality: enum cat_sch_idl_cntr_flow_reality
        :rtype: None
        """
        return self.sch_app_cntr_flow.AppSetFlowReality(i_e_flow_reality)

    def __repr__(self):
        return f'SchAppCntrFlow(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.point import Point
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.real_param import RealParam


class HybridShapePointBetween(Point):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.Point
                |                             HybridShapePointBetween
                | 
                | Represents the hybrid shape PointBetween feature object.
                | Role: To access the data of the hybrid shape PointBetween feature
                | object.
                | This data includes:
                | 
                |     The first reference point
                |     The second reference point 
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_point_between = com_object

    @property
    def first_point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstPoint() As Reference
                | 
                |     Returns or sets the first reference point.
                |     Sub-element(s) supported (see Boundary object): Vertex.
                | 
                |     Example:
                |         This example retrieves in RefPoint1 the first reference point for the
                |         PointBetween hybrid shape feature.
                | 
                |          Dim RefPoint1 As Reference
                |          Set RefPoint1 = PointBetween.FirstPoint

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_point_between.FirstPoint)

    @first_point.setter
    def first_point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_point_between.FirstPoint = reference_point.com_object

    @property
    def orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Orientation() As long
                | 
                |     Returns or sets the orientation. Role:
                |     Orientation = 1 means that distance is measured from the second point
                | 
                |     Example:
                |         This example retrieves in Orient the orientation for the PointBetween
                |         hybrid shape feature.
                | 
                |          Dim Orient As long
                |          Set Orient = PointBetween.Orientation

        :rtype: int
        """

        return self.hybrid_shape_point_between.Orientation

    @orientation.setter
    def orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_point_between.Orientation = value

    @property
    def ratio(self) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Ratio() As RealParam (Read Only)
                | 
                |     Get the ratio. Role:
                |     if d1 is the distance between the first point and the created point, and d2 is the distance
                |     between the first point and the second point, then ratio = d1/d2.
                | 
                |     Example:
                |         This example retrieves in ratio the orientation for the PointBetween
                |         hybrid shape feature.
                | 
                |          Dim ratio  As CATIARealParam
                |          Get ratio = PointBetween.Ratio

        :rtype: RealParam
        """

        return RealParam(self.hybrid_shape_point_between.Ratio)

    @property
    def second_point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondPoint() As Reference
                | 
                |     Returns or sets the second reference point.
                |     Sub-element(s) supported (see Boundary object): Vertex.
                | 
                |     Example:
                |         This example retrieves in RefPoint2 the second reference point for the
                |         PointBetween hybrid shape feature.
                | 
                |          Dim RefPoint2 As Reference
                |          Set RefPoint2 = PointBetween.SecondPoint

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_point_between.SecondPoint)

    @second_point.setter
    def second_point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_point_between.SecondPoint = reference_point.com_object

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Support() As Reference
                | 
                |     Returns or Sets the support.
                |     Note: the support can be surface or curve. It is not
                |     mandatory
                | 
                |     Sub-element(s) supported (see Boundary object): Face and TriDimFeatEdge and
                |     BiDimFeatEdge.
                | 
                |     Example:
                |         This example retrieves in oSupport the support(if it exist) for the
                |         PointBetween hybrid shape feature.
                | 
                |          Dim oSupport As Reference 
                |          Set oSupport = PointBetween.Support

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_point_between.Support)

    @support.setter
    def support(self, reference_support: Reference):
        """
        :param Reference reference_support:
        """

        self.hybrid_shape_point_between.Support = reference_support.com_object

    def __repr__(self):
        return f'HybridShapePointBetween(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class CompositesMaterial(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CompositesMaterial
                | 
                | Represents a Composites Material object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.composites_material = com_object

    @property
    def cured_thickness(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CuredThickness() As double
                | 
                |     returns or set the cured thicknes defined in Composites tab in mm.

        :rtype: float
        """

        return self.composites_material.CuredThickness

    @cured_thickness.setter
    def cured_thickness(self, value: float):
        """
        :param float value:
        """

        self.composites_material.CuredThickness = value

    @property
    def fabric_width(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FabricWidth() As double
                | 
                |     returns or set the fabric width defined in Composites tab in mm.

        :rtype: float
        """

        return self.composites_material.FabricWidth

    @fabric_width.setter
    def fabric_width(self, value: float):
        """
        :param float value:
        """

        self.composites_material.FabricWidth = value

    @property
    def limit_deformation(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LimitDeformation() As double
                | 
                |     returns or set the limit deformation defined in Composites tab in radian.

        :rtype: float
        """

        return self.composites_material.LimitDeformation

    @limit_deformation.setter
    def limit_deformation(self, value: float):
        """
        :param float value:
        """

        self.composites_material.LimitDeformation = value

    @property
    def mass_cost(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MassCost() As double
                | 
                |     returns or set the cost per mess defined in Composites tab in $ per kg.

        :rtype: float
        """

        return self.composites_material.MassCost

    @mass_cost.setter
    def mass_cost(self, value: float):
        """
        :param float value:
        """

        self.composites_material.MassCost = value

    @property
    def material_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaterialType() As short
                | 
                |     returns or set the material type defined in Composites tab. the input or
                |     output value is the following: 1 for Undefiened 2 for Unidirectional 3 for Bi
                |     Directional 4 for NCF (Non Crimp Fabric) 5 for Non Structural

        :rtype: int
        """

        return self.composites_material.MaterialType

    @material_type.setter
    def material_type(self, value: int):
        """
        :param int value:
        """

        self.composites_material.MaterialType = value

    @property
    def max_deformation(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxDeformation() As double
                | 
                |     returns or set the maximum deformation defined in Composites tab in radian.

        :rtype: float
        """

        return self.composites_material.MaxDeformation

    @max_deformation.setter
    def max_deformation(self, value: float):
        """
        :param float value:
        """

        self.composites_material.MaxDeformation = value

    @property
    def surfacic_weigth(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SurfacicWeigth() As double
                | 
                |     returns or set the surfacic weigth defined in Composites tab in kg per m2.

        :rtype: float
        """

        return self.composites_material.SurfacicWeigth

    @surfacic_weigth.setter
    def surfacic_weigth(self, value: float):
        """
        :param float value:
        """

        self.composites_material.SurfacicWeigth = value

    @property
    def uncured_thickness(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UncuredThickness() As double
                | 
                |     returns or set the uncured thicknes defined in Composites tab in mm.

        :rtype: float
        """

        return self.composites_material.UncuredThickness

    @uncured_thickness.setter
    def uncured_thickness(self, value: float):
        """
        :param float value:
        """

        self.composites_material.UncuredThickness = value

    def create_composites_data(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateCompositesData()
                | 
                |     Create a default composites properties on the current material.

        :rtype: None
        """
        return self.composites_material.CreateCompositesData()

    def exist_composites_data(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ExistCompositesData() As short
                | 
                |     Returns true if a composites properties exists on the current material.

        :rtype: int
        """
        return self.composites_material.ExistCompositesData()

    def __repr__(self):
        return f'CompositesMaterial(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_output_request import ABQOutputRequest


class ABQFHOutputRequest(ABQOutputRequest):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQOutputRequest
                |                         ABQFHOutputRequest
                | 
                | Represents the base interface for field and history output request
                | objects.
                | Role: The ABQFHOutputRequest interface manages the common properties of field
                | and history output requests.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abqfh_output_request = com_object

    @property
    def equally_spaced_incr(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EquallySpacedIncr(long iAtEquallySpacedIncr) (Write
                | Only)
                | 
                |     For explicit dynamic step: Sets request for output results at equally
                |     spaced increments.
                | 
                |     Parameters:
                | 
                |         iAtEquallySpacedIncr
                |             The increment number which allows the user to set output results at
                |             this interval

        :rtype: int
        """

        return self.abqfh_output_request.EquallySpacedIncr

    @equally_spaced_incr.setter
    def equally_spaced_incr(self, value: int):
        """
        :param int value:
        """

        self.abqfh_output_request.EquallySpacedIncr = value

    @property
    def every_x_incr_of_time(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EveryXIncrOfTime(double iAtEveryXIncr) (Write
                | Only)
                | 
                |     For explicit dynamic step: Sets request for output results at every
                |     specified units of time.
                | 
                |     Parameters:
                | 
                |         iAtEveryXIncr
                |             The time interval which allows the user to set output results at
                |             this interval

        :rtype: int
        """

        return self.abqfh_output_request.EveryXIncrOfTime

    @every_x_incr_of_time.setter
    def every_x_incr_of_time(self, value: int):
        """
        :param int value:
        """

        self.abqfh_output_request.EveryXIncrOfTime = value

    @property
    def output_at_def_or_all_sec_pts(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OutputAtDefOrAllSecPts(ABQOutputAtSecPts iOutputAtSecPts) (Write
                | Only)
                | 
                |     Sets request for output results at section points.
                | 
                |     Parameters:
                | 
                |         iOutputAtSecPts
                |             The option to request output results at section points: Default or
                |             All
                | 
                |             Legal values:
                | 
                |             "ABQDEFAULTSECPTS"
                |             "ABQALLSECPTS"

        :return: enum abq_output_at_sec_pts
        :rtype: int
        """

        return self.abqfh_output_request.OutputAtDefOrAllSecPts

    @output_at_def_or_all_sec_pts.setter
    def output_at_def_or_all_sec_pts(self, value: int):
        """
        :param int value:
        """

        self.abqfh_output_request.OutputAtDefOrAllSecPts = int

    @property
    def pre_select_default_or_all(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PreSelectDefaultOrAll(ABQOutputVariableType iOutputVarType) (Write
                | Only)
                | 
                |     Sets request for results for preselect default or ALL
                |     variables.
                | 
                |     Parameters:
                | 
                |         iOutputVarType
                |             The option to request output results for set of variables:
                |             Preselected or All
                | 
                |             Legal values:
                | 
                |             "ABQPRESELECTDEFVAR"
                |             "ABQALLVAR"

        :return: enum abq_output_variable_type
        :rtype: int
        """

        return self.abqfh_output_request.PreSelectDefaultOrAll

    @pre_select_default_or_all.setter
    def pre_select_default_or_all(self, value: int):
        """
        :param int value:
        """

        self.abqfh_output_request.PreSelectDefaultOrAll = value

    @property
    def specified_modes(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SpecifiedModes(CATSafeArrayVariant iSpecifiedModes) (Write
                | Only)
                | 
                |     For frequency step: Sets request for output results at specified
                |     modes.
                | 
                |     Parameters:
                | 
                |         iSpecifiedModes
                |             The list of modes for which output is requested

        :rtype: int
        """

        return self.abqfh_output_request.SpecifiedModes

    @specified_modes.setter
    def specified_modes(self, value: int):
        """
        :param int value:
        """

        self.abqfh_output_request.SpecifiedModes = value

    @property
    def specified_output_variables(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SpecifiedOutputVariables(CATBSTR iVariableNameBSTR) (Write
                | Only)
                | 
                |     Sets the specified variables for which results are
                |     requested.
                | 
                |     Parameters:
                | 
                |         iVariableNameBSTR
                |             The list of variables for which output is requested For example: If
                |             user wants to request output for variables 'U' and 'S', then iVariableNameBSTR
                |             will be "U, S"

        :rtype: int
        """

        return self.abqfh_output_request.SpecifiedOutputVariables

    @specified_output_variables.setter
    def specified_output_variables(self, value: int):
        """
        :param int value:
        """

        self.abqfh_output_request.SpecifiedOutputVariables = value

    @property
    def specified_sec_pts(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SpecifiedSecPts(CATSafeArrayVariant iSpecifiedSecPts) (Write
                | Only)
                | 
                |     Sets request for output results at specified section
                |     points.
                | 
                |     Parameters:
                | 
                |         iSpecifiedSecPts
                |             The list of section points at which output is
                |             requested

        :rtype: int
        """

        return self.abqfh_output_request.SpecifiedSecPts

    @specified_sec_pts.setter
    def specified_sec_pts(self, value: int):
        """
        :param int value:
        """

        self.abqfh_output_request.SpecifiedSecPts = value

    @property
    def timing_flag(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TimingFlag() As boolean
                | 
                |     Returns or sets a flag for output at approximate or exact times. A true
                |     value indicates that request for output results at approximate times and a
                |     false value for output results at exact times.
                | 
                |     Returns:
                |         A boolean specifying whether request for output results at approximate
                |         or exact times.

        :rtype: bool
        """

        return self.abqfh_output_request.TimingFlag

    @timing_flag.setter
    def timing_flag(self, value: bool):
        """
        :param bool value:
        """

        self.abqfh_output_request.TimingFlag = value

    def set_output_at_all_modes(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOutputAtAllModes()
                | 
                |     For frequency step: Sets request for output results at all modes.

        :rtype: None
        """
        return self.abqfh_output_request.SetOutputAtAllModes()

    def __repr__(self):
        return f'ABQFHOutputRequest(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.osm_interfaces.scene_product_data import SceneProductData
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class ProductScene(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ProductScene
                | 
                | Represent the Product-Scene.
                | A Product-Scene stores a state of a product in a given
                | ProductDocument.
                | 
                | This state is composed of product properties, graphical attibutes, activation
                | status and position for each component of the product.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.product_scene = com_object

    @property
    def type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CatSceneType (Read Only)
                | 
                |     Returns the type of the Product-Scene.
                | 
                |     Example:
                | 
                |              This example reads the type of NewSceneDelta
                |              Product-Scene.
                |
                |             Dim type As CatSceneType
                |             type = NewSceneDelta.Type

        :return: enum cat_scene_type
        :rtype: int
        """

        return self.product_scene.Type

    def copy(self, i_type: int) -> 'ProductScene':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Copy(CatSceneType iType) As ProductScene
                | 
                |     Creates another Product-Scene from the current one with the possibility to
                |     have a different mode.
                | 
                |     Parameters:
                | 
                |         iType
                |             The Product-Scene type 
                | 
                |     Returns:
                |         The Product-Scene created from the current one. 
                |     Example:
                | 
                |              This example returns whether the CopyScene Product-Scene created
                |              from 
                |             the Configuration1 Product-Scene, with the DELTA
                |             mode.
                |
                |             Dim type As CatSceneType
                |             type = CatSceneTypeDelta
                |             Dim CopyScene As ProductScene
                |             CopyScene = Configuration1.Copy(type)

        :param int i_type: enum cat_scene_type
        :rtype: ProductScene
        """
        return ProductScene(self.product_scene.Copy(i_type))

    def exists_in_scene(self, i_product: Product) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ExistsInScene(Product iProduct) As boolean
                | 
                |     Returns whether the product has overloaded attributes in the
                |     Product-Scene.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The product 
                | 
                |     Returns:
                |         True if the Product-Scene overloads some of the product attributes.
                |         
                |     Example:
                | 
                |              This example returns whether the Engine product exists
                |              in
                |             the Configuration1 Product-Scene.
                |             
                | 
                |             ExistsInSc = Configuration1.ExistsInScene(Engine)

        :param Product i_product:
        :rtype: bool
        """
        return self.product_scene.ExistsInScene(i_product.com_object)

    def get_scene_product_data(self, i_product: Product) -> SceneProductData:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSceneProductData(Product iProduct) As
                | SceneProductData
                | 
                |     Returns the SceneProductData associated to the given product in the
                |     Product-Scene. If it does not exist yet, it is created.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The product 
                | 
                |     Returns:
                |         The SceneProductData associated to the given product. 
                |     Example:
                | 
                |              This example returns SceneProductData associated to Engine
                |              in
                |             the NewSceneDelta Product-Scene.
                |             
                | 
                |             Dim scenePrd As SceneProductData
                |             type = NewSceneDelta.GetSceneProductData(Engine)

        :param Product i_product:
        :rtype: SceneProductData
        """
        return SceneProductData(self.product_scene.GetSceneProductData(i_product.com_object))

    def __repr__(self):
        return f'ProductScene(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.relations import Relations
from pycatia.manufacturing_interfaces.manufacturing_features import ManufacturingFeatures
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingView(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingView
                | 
                | The Manufacturing View is the object that holds all the manufacturing features
                | of the model.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_view = com_object

    @property
    def manufacturing_features(self) -> ManufacturingFeatures:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ManufacturingFeatures() As ManufacturingFeatures (Read
                | Only)
                | 
                |     Returns the Manufacturing Features of a Manufacturing
                |     View.
                | 
                |     Example:
                |         The following example returns in ManufacturingFeatures the
                |         Manufacturing Features of the Manufacturing View
                |         MfgView:
                | 
                |          Set ManufacturingFeatures = MfgView.ManufacturingFeatures

        :rtype: ManufacturingFeatures
        """

        return ManufacturingFeatures(self.manufacturing_view.ManufacturingFeatures)

    @property
    def relations(self) -> Relations:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Relations() As Relations (Read Only)
                | 
                |     Returns the Relations Set owned by a Manufacturing View.
                | 
                |     Example:
                |         The following example returns in Relations the Relations Set of the
                |         Manufacturing View MfgView:
                | 
                |          Set Relations = MfgView.Relations

        :rtype: Relations
        """

        return Relations(self.manufacturing_view.Relations)

    def create_all_machinable_area_features_from_tech_results_of_udf(self, i_finish_part_product: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateAllMachinableAreaFeaturesFromTechResultsOfUDF(Product
                | iFinishPartProduct)
                | 
                |     Creates Machinable feature using TR of UDF.
                | 
                |     Example:
                |         The following example takes iFinishPartProduct and Create MAF in
                |         MfgView:
                | 
                |         MfgView.CreateAllMachinableAreaFeaturesFromTechResultsOfUDF(iFinishPartProduct)

        :param Product i_finish_part_product:
        :rtype: None
        """
        return self.manufacturing_view.CreateAllMachinableAreaFeaturesFromTechResultsOfUDF(
            i_finish_part_product.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_all_machinable_area_features_from_tech_results_of_udf'
        # # vba_code = """
        # # Public Function create_all_machinable_area_features_from_tech_results_of_udf(manufacturing_view)
        # #     Dim iFinishPartProduct (2)
        # #     manufacturing_view.CreateAllMachinableAreaFeaturesFromTechResultsOfUDF iFinishPartProduct
        # #     create_all_machinable_area_features_from_tech_results_of_udf = iFinishPartProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ManufacturingView(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingOutput(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingOutput
                | 
                | Object that represents the output machining code.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_output = com_object

    @property
    def size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Size() As long (Read Only)
                | 
                |     Returns the number of bytes written to this data output.
                | 
                |     Parameters:
                | 
                |         oBytes
                |             The integer value of the number of bytes

        :rtype: int
        """

        return self.manufacturing_output.Size

    def close_stream(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CloseStream()
                | 
                |     Close the Stream.

        :rtype: None
        """
        return self.manufacturing_output.CloseStream()

    def decrement_tabulation(self, i_tab: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DecrementTabulation(long iTab)
                | 
                |     Decrement the tabulation of the current block of text by the specified
                |     number of characters.

        :param int i_tab:
        :rtype: None
        """
        return self.manufacturing_output.DecrementTabulation(i_tab)

    def end_block(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub EndBlock()
                | 
                |     Specify that the Block is ended.

        :rtype: None
        """
        return self.manufacturing_output.EndBlock()

    def end_line(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub EndLine()
                | 
                |     Specify that the line is ended.

        :rtype: None
        """
        return self.manufacturing_output.EndLine()

    def flush(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Flush()
                | 
                |     Flush all Data in the Stream.

        :rtype: None
        """
        return self.manufacturing_output.Flush()

    def increment_tabulation(self, i_tab: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub IncrementTabulation(long iTab)
                | 
                |     Increment the tabulation of the current block of text by the specified
                |     number of characters.

        :param int i_tab:
        :rtype: None
        """
        return self.manufacturing_output.IncrementTabulation(i_tab)

    def new_block(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub NewBlock()
                | 
                |     Create a New Block in the underlying output stream.

        :rtype: None
        """
        return self.manufacturing_output.NewBlock()

    def new_line(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub NewLine()
                | 
                |     Create a New Line in the underlying output stream.

        :rtype: None
        """
        return self.manufacturing_output.NewLine()

    def set_buffer_length(self, i_lines: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetBufferLength(long iLines)
                | 
                |     Set the number of lines of the buffer before it will be flushed (default is
                |     200).
                | 
                |     Parameters:
                | 
                |         iLines
                |             The integer value of the number of lines

        :param int i_lines:
        :rtype: None
        """
        return self.manufacturing_output.SetBufferLength(i_lines)

    def write_chars(self, i_text: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub write_Chars(CATBSTR iText)
                | 
                |     Write the specified string to the underlying output stream.

        :param str i_text:
        :rtype: None
        """
        return self.manufacturing_output.write_Chars(i_text)

    def write_double(self, i_val: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub write_Double(double iVal)
                | 
                |     Write the specified double to the underlying output stream.

        :param float i_val:
        :rtype: None
        """
        return self.manufacturing_output.write_Double(i_val)

    def write_long(self, i_val: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub write_Long(long iVal)
                | 
                |     Write the specified long to the underlying output stream.

        :param int i_val:
        :rtype: None
        """
        return self.manufacturing_output.write_Long(i_val)

    def __repr__(self):
        return f'ManufacturingOutput(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.cat_mat_interfaces.material_family import MaterialFamily
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class MaterialFamilies(Collection):
    """
    .. note::
        :class: toggle

        CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

            | System.IUnknown
            |     System.IDispatch
            |         System.CATBaseUnknown
            |             System.CATBaseDispatch
            |                 System.Collection
            |                     MaterialFamilies
            |
            | A collection of all the MaterialFamily objects.
            | This collection is currently managed by a CATIAMaterialDocument
            | object.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.material_families = com_object

    def add(self) -> MaterialFamily:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add() As MaterialFamily
                |
                |     Adds a new material family to the MaterialFamilies collection.
                |
                |
                | Example:
                |     The following adds a material family to the collection
                |     attached to a document. This document must be a
                |     MaterialDocument object.
                |
                |      FileToOpen = "e:\\users\\ast\\materials\\Catalog.CATMaterial"
                |      Dim MyDocument As MaterialDocument
                |      Set MyDocument = Documents.Open(FileToOpen)
                |      Dim MyMaterialFamily As MaterialFamily
                |      Set MyMaterialFamily = MyDocument.MaterialFamilies.Add

        :rtype: MaterialFamily
        """
        return MaterialFamily(self.material_families.Add())

    def item(self, i_index: cat_variant) -> MaterialFamily:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As MaterialFamily
                |
                |     Returns a material family from its index in the
                |     MaterialFamilies collection.
                |
                |     Parameters:
                |
                |         iIndex
                |             The index of the material family to retrieve in
                |             the collection of material families. Compared with
                |             other collections, you cannot use the name of
                |             the material family as argument.
                |
                |     Returns:
                |         The retrieved material family
                |
                | Example:
                |     The following example returns in MyMaterialFamily the
                |     sixth
                |     material family in the collection.
                |
                |      Dim MyMaterialFamily As MaterialFamily
                |      Set MyMaterialFamily = MaterialFamilies.Item(6)

        :param cat_variant i_index:
        :rtype: MaterialFamily
        """
        return MaterialFamily(self.material_families.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                |
                |     Removes a material family from the MaterialFamilies
                |     collection.
                |
                |     Parameters:
                |
                |         iIndex
                |             The index of the material family to remove.
                |             Compared with other collections, you cannot use
                |             the name of the material family as argument.
                |
                |
                |     Example:
                |         The following example removes the second material
                |         family in the collection attached to the active
                |         document. This document must be a MaterialDocument
                |         object.
                |
                |      FileToOpen = "e:\\users\\ast\\materials\\Catalog.CATMaterial"
                |      Dim MyDocument As MaterialDocument
                |      Set MyDocument = Documents.Open(FileToOpen)
                |      MyDocument.MaterialFamilies.Remove(2)

        :param cat_variant i_index:
        :rtype: None
        """
        self.material_families.Remove(i_index)

    def __repr__(self):
        return f'MaterialFamilies(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.boundary import Boundary
from pycatia.sketcher_interfaces.sketch import Sketch
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Sketches(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Sketches
                | 
                | The body's collection of sketches not yet used by any shape.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Sketch)
        self.sketches = com_object

    def add(self, i_plane: Reference) -> Sketch:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Add(Reference iPlane) As Sketch
                | 
                |     Creates a new sketch and adds it to the sketch collection. The sketch
                |     creation implies to specify a supporting plane. Once created, the sketch
                |     exists, but is empty. You must use the Sketch.OpenEdition method to begin to
                |     edit it.
                | 
                |     Parameters:
                | 
                |         iPlane
                |             The sketch supporting plane
                |             The following 
                | 
                |         Boundary object is supported: PlanarFace. 
                |     Returns:
                |         oNewSketch The created sketch 
                |     Example:
                |         This example creates the newSketch sketch on the XY plane of the myPart
                |         part:
                | 
                |          Set XYPlane = myPart.OriginElements.PlaneXY()
                |          Set newSketch = myPart.Sketches.Add(XYPlane)

        :param Reference i_plane:
        :rtype: Sketch
        """
        return Sketch(self.sketches.Add(i_plane.com_object))

    def get_boundary(self, i_label: str) -> Boundary:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetBoundary(CATBSTR iLabel) As Boundary
                | 
                |     Returns a boundary using its label.
                | 
                |     Parameters:
                | 
                |         iLabel
                |             Identification of the 
                | 
                |         Boundary object. See Reference.DisplayName. 
                |     Returns:
                |         The retrieved boundary

        :param str i_label:
        :rtype: Boundary
        """
        return Boundary(self.sketches.GetBoundary(i_label))

    def item(self, i_index: cat_variant) -> Sketch:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Item(CATVariant iIndex) As Sketch
                | 
                |     Returns a sketch using its index or its name from the Sketches
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the sketch to retrieve from the collection
                |             of sketches. As a numerics, this index is the rank of the sketch in the
                |             collection. The index of the first sketch in the collection is 1, and the index
                |             of the last sketch is Count. As a string, it is the name you assigned to the
                |             sketch using the 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved sketch 
                |     Example:
                |         This example retrieves the last item in the collection
                |         sketches.
                | 
                |          Set lastSketch = sketchList.Item(sketchList.Count)

        :param cat_variant i_index:
        :rtype: Sketch
        """
        return Sketch(self.sketches.Item(i_index))

    def __getitem__(self, n: int) -> Sketch:
        if (n + 1) > self.count:
            raise StopIteration

        return Sketch(self.sketches.Item(n + 1))

    def __iter__(self) -> Iterator[Sketch]:
        for i in range(self.count):
            yield self.child_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'Sketches(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.funct_system_interfaces.functional_facet import FunctionalFacet


class FunctNodeGraphLayout(FunctionalFacet):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATFunctSystemItf.FunctionalFacet
                |                         FunctNodeGraphLayout
                | 
                | Represents a CATIAFunctNodeGraphLayout.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.funct_node_graph_layout = com_object

    @property
    def height(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Height() As double (Read Only)
                | 
                |     Returns the Height coordinate.

        :rtype: float
        """

        return self.funct_node_graph_layout.Height

    @property
    def width(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Width() As double (Read Only)
                | 
                |     Returns the Width coordinate.

        :rtype: float
        """

        return self.funct_node_graph_layout.Width

    def set_height_and_width(self, i_height: float, i_width: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetHeightAndWidth(double iHeight,
                | double iWidth)
                | 
                |     Sets the height and width.
                | 
                |     Parameters:
                | 
                |         iHeight
                |             the height value. 
                |         iWidth
                |             the width value.

        :param float i_height:
        :param float i_width:
        :rtype: None
        """
        return self.funct_node_graph_layout.SetHeightAndWidth(i_height, i_width)

    def __repr__(self):
        return f'FunctNodeGraphLayout(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.reference import Reference
from pycatia.structure_interfaces.str_cutout_feature import StrCutoutFeature
from pycatia.structure_interfaces.str_nibbling_feature import StrNibblingFeature
from pycatia.system_interfaces.any_object import AnyObject


class StrFeatureFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     StrFeatureFactory
                | 
                | Represents the Factory Object for Structure Features.
                | The factory is retrieved using the StrPlate or StrMember
                | 
                | Example:
                |     The following example retrieves the Feature factory object from the
                |     Selection on ActiveDocument.
                | 
                |      Dim Plate As StrPlate
                |      Set Plate = strPlates.Item("Plate_007")
                |      Dim Sel As Selection
                |      Set Sel = CATIA.ActiveDocument.Selection
                |      ' Use the Add method to add Plate to selection
                |      Sel.Add Plate
                |      Dim Factory As StrFeatureFactory
                |      Set Factory = Sel.FindObject("CATIAStrFeatureFactory")
                |      
                | 
                |     Method Index
                |     AddCutoutWithAfterFormingMode
                |         Adds a Cutout Feature on Plate/Member using AfterForming Mode.
                |         
                |     AddCutoutWithBeforeFormingMode
                |         Adds a Cutout Feature on Plate/Member using BeforeForming Mode.
                |         
                |     AddNibbling
                |         Adds a Coping on Plate or Member. 
                | 
                |     Methods
                | 
                | o Func AddCutoutWithAfterFormingMode(	Reference 	iContour,
                | 	Reference 	iDirection) As StrCutoutFeature
                | 
                |     Adds a Cutout Feature on Plate/Member using AfterForming
                |     Mode.
                | 
                |     Parameters:
                | 
                |         iContour
                |             [in] The Sketch used to create the cutout. This must exist in the
                |             document. 
                |         iDirection
                |             [in] The direction in which the cutout should be created. Valid
                |             inputs are line created in sketch,3D Line. 
                |         oCutout[out]
                |             The CutOut Feature 
                |         @return
                |             S_OK if everything ran ok.
                | 
                |             Example
                |             :
                |                 This example creates Cutout on Plate.
                | 
                |                  ' Define the Plate on which cutout is to be
                |                  created
                |                  Dim strPlates As strPlates
                |                  Set strPlates = rootProduct.GetTechnologicalObject("StructurePlates")
                |                  Dim PlateToCut As StrPlate
                |                  Set PlateToCut = strPlates.Item("Plate_012")
                |                 ' Add the Plate to Selection
                |                  Dim Sel As Selection
                |                  Set Sel = CATIA.ActiveDocument.Selection
                |                  Sel.Add PlateToCut
                |                  'Get The factory from selection
                |                  Dim Factory As StrFeatureFactory
                |                  Set Factory = Sel.FindObject("CATIAStrFeatureFactory")
                |                  ' Select the Sketch profile exisitng in the
                |                  document
                |                  Dim sketch As Reference
                |                  Set sketch = rootProduct.CreateReferenceFromName("Product1/Grid/!Sketch.1")
                |                  ' Select the direction in which the cutout should be
                |                  created
                |                  Dim dir1 As Reference
                |                  Set dir1 = rootProduct.CreateReferenceFromName("Product1/Grid/!Sketch.2")
                |                  ' Create cutout
                |                  Dim Cutout1 As StrCutoutFeature
                |                  Set Cutout1 = Factory.AddCutoutWithAfterFormingMode(sketch, dir1)
                |                  
                | 
                | o Func AddCutoutWithBeforeFormingMode(	Reference 	iContour,
                | 	Reference 	iSurface) As StrCutoutFeature
                | 
                |     Adds a Cutout Feature on Plate/Member using BeforeForming
                |     Mode.
                | 
                |     Parameters:
                | 
                |         iContour
                |             [in] The Sketch used to create the cutout. This must exist in the
                |             document 
                |         iSurface
                |             [in] A Surface on which Plate/Member is created. 
                |         oCutout[out]
                |             The CutOut Feature 
                |         @return
                |             S_OK if everything ran ok.
                | 
                |             Example
                |             :
                |                 This example creates Cutout on Member.
                | 
                |                  'Define the Plate on which cutout is to be
                |                  created
                |                  Dim strPlates As strPlates
                |                  Set strPlates = rootProduct.GetTechnologicalObject("StructurePlates")
                |                  Dim PlateToCut As StrPlate
                |                  Set PlateToCut = strPlates.Item("Plate_012")
                |                  ' Add the Plate to Selection
                |                  Dim Sel As Selection
                |                  Set Sel = CATIA.ActiveDocument.Selection
                |                  Sel.Add PlateToCut
                |                  ' Get The factory from selection
                |                  Dim Factory As StrFeatureFactory
                |                  Set Factory = Sel.FindObject("CATIAStrFeatureFactory")
                |                  ' Select the Sketch profile exisitng in the
                |                  document
                |                  Dim sketch As Reference
                |                  Set sketch = rootProduct.CreateReferenceFromName("Product1/Grid/!Sketch.1")
                |                  ' Select the surface 
                |                  Dim Surface1 As Reference
                |                  Set Surface1 = rootProduct.CreateReferenceFromName("Product1/Grid/!Extrude.1")
                |                  ' Create cutout
                |                  Dim Cutout1 As StrCutoutFeature
                |                  Set Cutout1 = Factory.AddCutoutWithBeforeFormingMode(sketch, Surface1)
                |                  
                | 
                | o Func AddNibbling(	CATSafeArrayVariant
                | iListOfLimitingElements,
                | 	CATBSTR 	iNibblingType) As StrNibblingFeature
                | 
                |     Adds a Coping on Plate or Member.
                | 
                |     Parameters:
                | 
                |         iListOfLimitingElements
                |             [in] List of Limiting elements used for limiting the Plate/Member.
                |             Pass only one limit at a time. 
                |         iNibblingType
                |             [in] Possible Values for Plate:"Remove". Possible Values for
                |             Member:"Remove","ShortPoint","LongPoint","WeldCut". For Defining further
                |             attributes refer CATIAStrNibblingFeature. 
                |         oNibblingFeature[out]
                |             The Nibbled Plate/Member. 
                |         @return
                |             S_OK if everything ran ok.
                | 
                |             Example
                |             :
                |                 This example creates Coping on Plate.
                | 
                |                  Dim Limitplate1 As StrPlate
                |                  Set Limitplate1 = strPlates.Item("Plate_008")
                |                  Dim Listoflimits As Variant
                |                  Set Listoflimits(0) =Limitplate1
                |                  Dim NibblingFeature As StrNibblingFeature
                |                  Set NibblingFeature = Factory.AddNibbling(Listoflimits, "Remove")
                |                  
                | 
                |     Copyright © 1999-2011, Dassault Systèmes. All rights
                |     reserved.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.str_feature_factory = com_object

    def add_cutout_with_after_forming_mode(self, i_contour: Reference, i_direction: Reference) -> StrCutoutFeature:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddCutoutWithAfterFormingMode(Reference iContour,
                | Reference iDirection) As StrCutoutFeature
                | 
                |     Adds a Cutout Feature on Plate/Member using AfterForming
                |     Mode.
                | 
                |     Parameters:
                | 
                |         iContour
                |             [in] The Sketch used to create the cutout. This must exist in the
                |             document. 
                |         iDirection
                |             [in] The direction in which the cutout should be created. Valid
                |             inputs are line created in sketch,3D Line. 
                |         oCutout[out]
                |             The CutOut Feature 
                |         @return
                |             S_OK if everything ran ok.
                | 
                |             Example
                |             :
                |                 This example creates Cutout on Plate.
                | 
                |                  ' Define the Plate on which cutout is to be
                |                  created
                |                  Dim strPlates As strPlates
                |                  Set strPlates = rootProduct.GetTechnologicalObject("StructurePlates")
                |                  Dim PlateToCut As StrPlate
                |                  Set PlateToCut = strPlates.Item("Plate_012")
                |                 ' Add the Plate to Selection
                |                  Dim Sel As Selection
                |                  Set Sel = CATIA.ActiveDocument.Selection
                |                  Sel.Add PlateToCut
                |                  'Get The factory from selection
                |                  Dim Factory As StrFeatureFactory
                |                  Set Factory = Sel.FindObject("CATIAStrFeatureFactory")
                |                  ' Select the Sketch profile exisitng in the
                |                  document
                |                  Dim sketch As Reference
                |                  Set sketch = rootProduct.CreateReferenceFromName("Product1/Grid/!Sketch.1")
                |                  ' Select the direction in which the cutout should be
                |                  created
                |                  Dim dir1 As Reference
                |                  Set dir1 = rootProduct.CreateReferenceFromName("Product1/Grid/!Sketch.2")
                |                  ' Create cutout
                |                  Dim Cutout1 As StrCutoutFeature
                |                  Set Cutout1 = Factory.AddCutoutWithAfterFormingMode(sketch, dir1)

        :param Reference i_contour:
        :param Reference i_direction:
        :rtype: StrCutoutFeature
        """
        return StrCutoutFeature(
            self.str_feature_factory.AddCutoutWithAfterFormingMode(i_contour.com_object, i_direction.com_object))

    def add_cutout_with_before_forming_mode(self, i_contour: Reference, i_surface: Reference) -> StrCutoutFeature:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddCutoutWithBeforeFormingMode(Reference iContour,
                | Reference iSurface) As StrCutoutFeature
                | 
                |     Adds a Cutout Feature on Plate/Member using BeforeForming
                |     Mode.
                | 
                |     Parameters:
                | 
                |         iContour
                |             [in] The Sketch used to create the cutout. This must exist in the
                |             document 
                |         iSurface
                |             [in] A Surface on which Plate/Member is created. 
                |         oCutout[out]
                |             The CutOut Feature 
                |         @return
                |             S_OK if everything ran ok.
                | 
                |             Example
                |             :
                |                 This example creates Cutout on Member.
                | 
                |                  'Define the Plate on which cutout is to be
                |                  created
                |                  Dim strPlates As strPlates
                |                  Set strPlates = rootProduct.GetTechnologicalObject("StructurePlates")
                |                  Dim PlateToCut As StrPlate
                |                  Set PlateToCut = strPlates.Item("Plate_012")
                |                  ' Add the Plate to Selection
                |                  Dim Sel As Selection
                |                  Set Sel = CATIA.ActiveDocument.Selection
                |                  Sel.Add PlateToCut
                |                  ' Get The factory from selection
                |                  Dim Factory As StrFeatureFactory
                |                  Set Factory = Sel.FindObject("CATIAStrFeatureFactory")
                |                  ' Select the Sketch profile exisitng in the
                |                  document
                |                  Dim sketch As Reference
                |                  Set sketch = rootProduct.CreateReferenceFromName("Product1/Grid/!Sketch.1")
                |                  ' Select the surface 
                |                  Dim Surface1 As Reference
                |                  Set Surface1 = rootProduct.CreateReferenceFromName("Product1/Grid/!Extrude.1")
                |                  ' Create cutout
                |                  Dim Cutout1 As StrCutoutFeature
                |                  Set Cutout1 = Factory.AddCutoutWithBeforeFormingMode(sketch, Surface1)

        :param Reference i_contour:
        :param Reference i_surface:
        :rtype: StrCutoutFeature
        """
        return StrCutoutFeature(
            self.str_feature_factory.AddCutoutWithBeforeFormingMode(i_contour.com_object, i_surface.com_object))

    def add_nibbling(self, i_list_of_limiting_elements: tuple, i_nibbling_type: str) -> StrNibblingFeature:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddNibbling(CATSafeArrayVariant
                | iListOfLimitingElements,
                | CATBSTR iNibblingType) As StrNibblingFeature
                | 
                |     Adds a Coping on Plate or Member.
                | 
                |     Parameters:
                | 
                |         iListOfLimitingElements
                |             [in] List of Limiting elements used for limiting the Plate/Member.
                |             Pass only one limit at a time. 
                |         iNibblingType
                |             [in] Possible Values for Plate:"Remove". Possible Values for
                |             Member:"Remove","ShortPoint","LongPoint","WeldCut". For Defining further
                |             attributes refer CATIAStrNibblingFeature. 
                |         oNibblingFeature[out]
                |             The Nibbled Plate/Member. 
                |         @return
                |             S_OK if everything ran ok.
                | 
                |             Example
                |             :
                |                 This example creates Coping on Plate.
                | 
                |                  Dim Limitplate1 As StrPlate
                |                  Set Limitplate1 = strPlates.Item("Plate_008")
                |                  Dim Listoflimits As Variant
                |                  Set Listoflimits(0) =Limitplate1
                |                  Dim NibblingFeature As StrNibblingFeature
                |                  Set NibblingFeature = Factory.AddNibbling(Listoflimits, "Remove")
                |                  
                | 
                |     Copyright © 1999-2011, Dassault Systèmes. All rights
                |     reserved.

        :param tuple i_list_of_limiting_elements:
        :param str i_nibbling_type:
        :rtype: StrNibblingFeature
        """
        return StrNibblingFeature(self.str_feature_factory.AddNibbling(i_list_of_limiting_elements, i_nibbling_type))

    def __repr__(self):
        return f'StrFeatureFactory(name="{self.name}")'
